# Licensed to the Apache Software Foundation (ASF) under one or more
# contributor license agreements.  See the NOTICE file distributed with
# this work for additional information regarding copyright ownership.
# The ASF licenses this file to You under the Apache License, Version 2.0
# (the "License"); you may not use this file except in compliance with
# the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Set environment variables here.
# Collector Log directory for log4j
export AMS_COLLECTOR_LOG_DIR=/tmp

# Monitor Log directory for outfile
export AMS_MONITOR_LOG_DIR=/tmp

# Collector pid directory
export AMS_COLLECTOR_PID_DIR=/tmp

# Monitor pid directory
export AMS_MONITOR_PID_DIR=/tmp

# AMS HBase pid directory
export AMS_HBASE_PID_DIR=/tmp

# AMS Collector heapsize
export AMS_COLLECTOR_HEAPSIZE=512m